Weekday enum

Weekdays.

Inheritance
Available extensions

Values

monday → const Weekday
const Weekday(1)
tuesday → const Weekday
const Weekday(2)
wednesday → const Weekday
const Weekday(3)
thursday → const Weekday
const Weekday(4)
friday → const Weekday
const Weekday(5)
saturday → const Weekday
const Weekday(6)
sunday → const Weekday
const Weekday(7)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isoIndex → int
The ISO 8601 standard index, where Monday is 1 and Sunday is 7.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Weekday>
A constant List of the values in this enum, in order of their declaration.