CaseMappingExt extension

Extension methods on String for locale-sensitive case mapping.

See CaseMapping for more details. This provides convenient methods directly on String instances.

on

Methods

toLocaleLowerCase(Locale locale) → String

Available on String, provided by the CaseMappingExt extension

Returns the string converted to lower case, taking the given locale into account.
toLocaleUpperCase(Locale locale) → String

Available on String, provided by the CaseMappingExt extension

Returns the string converted to upper case, taking the given locale into account.