CompactNotation class final

Compact notation, used for formatting large numbers in a shorter form (e.g., 1,000,000 as "1M").

Inheritance

Constructors

CompactNotation({CompactDisplay compactDisplay = CompactDisplay.short})

Properties

compactDisplay → CompactDisplay
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited