CurrencyStyle class final

Formats a number as a currency.

Inheritance

Constructors

CurrencyStyle({required String currency, CurrencySign sign = CurrencySign.standard, CurrencyDisplay display = CurrencyDisplay.symbol})

Properties

currency → String
The currency code (e.g., 'USD').
final
display → CurrencyDisplay
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sign → CurrencySign
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited