FractionDigits class final

Control how many fraction digits to use in number formatting.

Constructors

FractionDigits({int? minimum, int? maximum})
Creates a FractionDigits instance with optional minimum and maximum fraction digits.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximum → int?
The maximum number of fraction digits to use.
final
minimum → int?
The minimum number of fraction digits to use.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited