UnitStyle class final

Formats a number with a unit.

Inheritance

Constructors

UnitStyle({required Unit unit, UnitDisplay unitDisplay = UnitDisplay.short})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → Unit
final
unitDisplay → UnitDisplay
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited